@@ -53,7 +53,7 @@
 #'   Recommended with length 10.
 #'   String to find the message in the code.
 #'   E.g. 10-digit random hex from
-#'   \url{https://onlinerandomtools.com/generate-random-hexadecimal-numbers}
+#'   \url{https://onlinetools.com/random/generate-random-hexadecimal-numbers}
 #' @param logfile_dir (Optional, String, default: "tempdir()")
 #'   The absolute path to folder where the logfile will be stored.
 #' @param headless (Optional, Boolean, default: TRUE)
@@ -348,8 +348,11 @@ feedback_to_logfile <-
     path_with_file <- file.path(logfile_dir, "logfile.log") %>%
       normalizePath(mustWork = FALSE)
 
-    if (!file.exists(path_with_file)) {
+    if (!dir.exists(logfile_dir)) {
       dir.create(logfile_dir, recursive = TRUE)
+    }
+
+    if (!file.exists(path_with_file)) {
       file.create(path_with_file)
     }
 
